==> webgui_7.8.21.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Account_Profile.pm <==
package WebGUI::i18n::Spanish::Account_Profile;
use utf8;
our $I18N = {
  'back label' => {
    'lastUpdated' => '1232558331',
    'message' => 'Regresar al sitio'
  },
  'back to profile label' => {
    'lastUpdated' => '1232558355',
    'message' => 'Regresar al perfil'
  },
  'edit my profile' => {
    'lastUpdated' => '1232558367',
    'message' => 'Editar mi perfil'
  },
  'error label' => {
    'lastUpdated' => '1232558377',
    'message' => 'Error'
  },
  'friends only' => {
    'lastUpdated' => '1252509946',
    'message' => 'Su perfil es visible a amigos'
  },
  'friends only label' => {
    'lastUpdated' => '1232557978',
    'message' => 'Amigos solamente'
  },
  'member since' => {
    'lastUpdated' => '1232558404',
    'message' => 'Miembro desde'
  },
  'private label' => {
    'lastUpdated' => '1232558431',
    'message' => 'Privado'
  },
  'private profile' => {
    'lastUpdated' => '1232558009',
    'message' => 'Su perfil es privado'
  },
  'profile as others label' => {
    'lastUpdated' => '1252509970',
    'message' => 'Ver mi perfil como lo ven otros'
  },
  'profile edit layout template hoverHelp' => {
    'lastUpdated' => '1233076308',
    'message' => 'Seleccione un diseño desde la lista para mostrar el perfil del usuario para editarlo.'
  },
  'profile edit layout template label' => {
    'lastUpdated' => '1252510008',
    'message' => 'Plantilla para Layout'
  },
  'profile edit template hoverHelp' => {
    'lastUpdated' => '1233076390',
    'message' => 'Seleccione la plntilla principal para editar un perfil'
  },
  'profile edit template label' => {
    'lastUpdated' => '1252509993',
    'message' => 'Plantilla para Editar Perfil'
  },
  'profile error template hoverHelp' => {
    'lastUpdated' => '1233076360',
    'message' => 'Seleccione la plantilla a usar para mostrar los errores del perfil de usuario.'
  },
  'profile error template label' => {
    'lastUpdated' => '1252510019',
    'message' => 'Plantilla para Errores'
  },
  'profile layout template hoverHelp' => {
    'lastUpdated' => '1233076221',
    'message' => 'Seleccione un diseño de la lista para mostrar los distintos plugins de cuenta que son utilizables por el usuario actual, así como el contenido del plugin actualmente elegido.'
  },
  'profile layout template label' => {
    'lastUpdated' => '1233076145',
    'message' => 'Editar Plantilla de Diseño'
  },
  'profile not public error' => {
    'lastUpdated' => '1232558508',
    'message' => 'El perfil de este usuario no es público'
  },
  'profile style template hoverHelp' => {
    'lastUpdated' => '1233076112',
    'message' => 'Seleccione un plantilla de estilo desde la lista para adjuntarla en el perfil.'
  },
  'profile style template label' => {
    'lastUpdated' => '1233076081',
    'message' => 'Plantilla de Estilo'
  },
  'profile view template hoverHelp' => {
    'lastUpdated' => '1233076069',
    'message' => 'Seleccione la plantilla principal para ver un perfil.'
  },
  'profile view template label' => {
    'lastUpdated' => '1232558315',
    'message' => 'Ver Template'
  },
  'public label' => {
    'lastUpdated' => '1232557992',
    'message' => 'Público'
  },
  'public profile' => {
    'lastUpdated' => '1232557981',
    'message' => 'Tu perfil es público'
  },
  'required field' => {
    'lastUpdated' => '1232558170',
    'message' => 'Obligatorio'
  },
  'save changes' => {
    'lastUpdated' => '1232557967',
    'message' => 'guardar cambios'
  },
  'send friend request label' => {
    'lastUpdated' => '1232558189',
    'message' => 'Enviar Petición Amigo'
  },
  'send private message label' => {
    'lastUpdated' => '1232558270',
    'message' => 'Enviar Mensaje Privado'
  },
  'set by admin' => {
    'lastUpdated' => '1232558250',
    'message' => 'El administrador del sitio ha fijado este campo para no sea visible'
  },
  'title' => {
    'lastUpdated' => '1232558001',
    'message' => 'Perfil'
  },
  'view my profile' => {
    'lastUpdated' => '1232557954',
    'message' => 'ver mi perfil'
  },
  'visitor profile restricted' => {
    'lastUpdated' => '1232558029',
    'message' => 'El perfil de los visitantes está restringido'
  }
}
;

1;

==> webgui_7.10.29.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Account_Profile.pm <==
package WebGUI::i18n::Spanish::Account_Profile;
use utf8;
our $I18N = {
  'ascending' => {
    'lastUpdated' => '1309213925',
    'message' => 'Ascendente'
  },
  'assetManagerSortColumn label' => {
    'lastUpdated' => '1309214027',
    'message' => 'Ordenar Activos por'
  },
  'assetManagerSortDirection label' => {
    'lastUpdated' => '1309214015',
    'message' => 'Activos con Orden'
  },
  'back label' => {
    'lastUpdated' => '1232558331',
    'message' => 'Regresar al sitio'
  },
  'back to profile label' => {
    'lastUpdated' => '1232558355',
    'message' => 'Regresar al perfil'
  },
  'descending' => {
    'lastUpdated' => '1309213956',
    'message' => 'Descendiente'
  },
  'edit my profile' => {
    'lastUpdated' => '1232558367',
    'message' => 'Editar mi perfil'
  },
  'error label' => {
    'lastUpdated' => '1232558377',
    'message' => 'Error'
  },
  'friends only' => {
    'lastUpdated' => '1252509946',
    'message' => 'Su perfil es visible a amigos'
  },
  'friends only label' => {
    'lastUpdated' => '1232557978',
    'message' => 'Amigos solamente'
  },
  'member since' => {
    'lastUpdated' => '1232558404',
    'message' => 'Miembro desde'
  },
  'private label' => {
    'lastUpdated' => '1232558431',
    'message' => 'Privado'
  },
  'private profile' => {
    'lastUpdated' => '1232558009',
    'message' => 'Su perfil es privado'
  },
  'profile as others label' => {
    'lastUpdated' => '1252509970',
    'message' => 'Ver mi perfil como lo ven otros'
  },
  'profile edit layout template hoverHelp' => {
    'lastUpdated' => '1233076308',
    'message' => 'Seleccione un diseño desde la lista para mostrar el perfil del usuario para editarlo.'
  },
  'profile edit layout template label' => {
    'lastUpdated' => '1252510008',
    'message' => 'Plantilla para Layout'
  },
  'profile edit template hoverHelp' => {
    'lastUpdated' => '1233076390',
    'message' => 'Seleccione la plntilla principal para editar un perfil'
  },
  'profile edit template label' => {
    'lastUpdated' => '1252509993',
    'message' => 'Plantilla para Editar Perfil'
  },
  'profile error template hoverHelp' => {
    'lastUpdated' => '1233076360',
    'message' => 'Seleccione la plantilla a usar para mostrar los errores del perfil de usuario.'
  },
  'profile error template label' => {
    'lastUpdated' => '1252510019',
    'message' => 'Plantilla para Errores'
  },
  'profile layout template hoverHelp' => {
    'lastUpdated' => '1233076221',
    'message' => 'Seleccione un diseño de la lista para mostrar los distintos plugins de cuenta que son utilizables por el usuario actual, así como el contenido del plugin actualmente elegido.'
  },
  'profile layout template label' => {
    'lastUpdated' => '1233076145',
    'message' => 'Editar Plantilla de Diseño'
  },
  'profile not public error' => {
    'lastUpdated' => '1232558508',
    'message' => 'El perfil de este usuario no es público'
  },
  'profile style template hoverHelp' => {
    'lastUpdated' => '1233076112',
    'message' => 'Seleccione un plantilla de estilo desde la lista para adjuntarla en el perfil.'
  },
  'profile style template label' => {
    'lastUpdated' => '1233076081',
    'message' => 'Plantilla de Estilo'
  },
  'profile view template hoverHelp' => {
    'lastUpdated' => '1233076069',
    'message' => 'Seleccione la plantilla principal para ver un perfil.'
  },
  'profile view template label' => {
    'lastUpdated' => '1232558315',
    'message' => 'Ver Template'
  },
  'public label' => {
    'lastUpdated' => '1232557992',
    'message' => 'Público'
  },
  'public profile' => {
    'lastUpdated' => '1232557981',
    'message' => 'Tu perfil es público'
  },
  'required field' => {
    'lastUpdated' => '1232558170',
    'message' => 'Obligatorio'
  },
  'save changes' => {
    'lastUpdated' => '1232557967',
    'message' => 'guardar cambios'
  },
  'send friend request label' => {
    'lastUpdated' => '1232558189',
    'message' => 'Enviar Petición Amigo'
  },
  'send private message label' => {
    'lastUpdated' => '1232558270',
    'message' => 'Enviar Mensaje Privado'
  },
  'set by admin' => {
    'lastUpdated' => '1232558250',
    'message' => 'El administrador del sitio ha fijado este campo para no sea visible'
  },
  'title' => {
    'lastUpdated' => '1232558001',
    'message' => 'Perfil'
  },
  'view my profile' => {
    'lastUpdated' => '1232557954',
    'message' => 'ver mi perfil'
  },
  'visitor profile restricted' => {
    'lastUpdated' => '1232558029',
    'message' => 'El perfil de los visitantes está restringido'
  }
}
;

1;
